
From: Adrian Bunk <bunk@stusta.de>

This patch contains the following cleanups:
- make some needlessly global code static
- #if 0 the following unused functions:
  - intrep.c: jffs_print_file
  - jffs_fm.c: jffs_print_node_ref

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/fs/jffs/inode-v23.c  |   10 +++----
 25-akpm/fs/jffs/intrep.c     |   60 ++++++++++++++++++++++++++++++-------------
 25-akpm/fs/jffs/intrep.h     |   32 +---------------------
 25-akpm/fs/jffs/jffs_fm.c    |   12 ++++++--
 25-akpm/fs/jffs/jffs_fm.h    |    6 +---
 25-akpm/include/linux/jffs.h |    1 
 6 files changed, 61 insertions(+), 60 deletions(-)

diff -puN fs/jffs/inode-v23.c~fs-jffs-misc-cleanups fs/jffs/inode-v23.c
--- 25/fs/jffs/inode-v23.c~fs-jffs-misc-cleanups	Thu Feb 17 17:04:36 2005
+++ 25-akpm/fs/jffs/inode-v23.c	Thu Feb 17 17:04:36 2005
@@ -334,7 +334,7 @@ out:
 } /* jffs_notify_change()  */
 
 
-struct inode *
+static struct inode *
 jffs_new_inode(const struct inode * dir, struct jffs_raw_inode *raw_inode,
 	       int * err)
 {
@@ -376,7 +376,7 @@ jffs_new_inode(const struct inode * dir,
 }
 
 /* Get statistics of the file system.  */
-int
+static int
 jffs_statfs(struct super_block *sb, struct kstatfs *buf)
 {
 	struct jffs_control *c = (struct jffs_control *) sb->s_fs_info;
@@ -410,7 +410,7 @@ jffs_statfs(struct super_block *sb, stru
 
 
 /* Rename a file.  */
-int
+static int
 jffs_rename(struct inode *old_dir, struct dentry *old_dentry,
 	    struct inode *new_dir, struct dentry *new_dentry)
 {
@@ -1739,7 +1739,7 @@ jffs_read_inode(struct inode *inode)
 }
 
 
-void
+static void
 jffs_delete_inode(struct inode *inode)
 {
 	struct jffs_file *f;
@@ -1762,7 +1762,7 @@ jffs_delete_inode(struct inode *inode)
 }
 
 
-void
+static void
 jffs_write_super(struct super_block *sb)
 {
 	struct jffs_control *c = (struct jffs_control *)sb->s_fs_info;
diff -puN fs/jffs/intrep.c~fs-jffs-misc-cleanups fs/jffs/intrep.c
--- 25/fs/jffs/intrep.c~fs-jffs-misc-cleanups	Thu Feb 17 17:04:36 2005
+++ 25-akpm/fs/jffs/intrep.c	Thu Feb 17 17:04:36 2005
@@ -72,7 +72,7 @@
 #include "jffs_fm.h"
 
 long no_jffs_node = 0;
-long no_jffs_file = 0;
+static long no_jffs_file = 0;
 #if defined(JFFS_MEMORY_DEBUG) && JFFS_MEMORY_DEBUG
 long no_jffs_control = 0;
 long no_jffs_raw_inode = 0;
@@ -85,6 +85,32 @@ long no_name = 0;
 
 static int jffs_scan_flash(struct jffs_control *c);
 static int jffs_update_file(struct jffs_file *f, struct jffs_node *node);
+static int jffs_build_file(struct jffs_file *f);
+static int jffs_free_file(struct jffs_file *f);
+static int jffs_free_node_list(struct jffs_file *f);
+static int jffs_garbage_collect_now(struct jffs_control *c);
+static int jffs_insert_file_into_hash(struct jffs_file *f);
+static int jffs_remove_redundant_nodes(struct jffs_file *f);
+
+/* Is there enough space on the flash?  */
+static inline int JFFS_ENOUGH_SPACE(struct jffs_control *c, __u32 space)
+{
+	struct jffs_fmcontrol *fmc = c->fmc;
+
+	while (1) {
+		if ((fmc->flash_size - (fmc->used_size + fmc->dirty_size))
+			>= fmc->min_free_size + space) {
+			return 1;
+		}
+		if (fmc->dirty_size < fmc->sector_size)
+			return 0;
+
+		if (jffs_garbage_collect_now(c)) {
+		  D1(printk("JFFS_ENOUGH_SPACE: jffs_garbage_collect_now() failed.\n"));
+		  return 0;
+		}
+	}
+}
 
 #if CONFIG_JFFS_FS_VERBOSE > 0
 static __u8
@@ -331,7 +357,7 @@ flash_erase_region(struct mtd_info *mtd,
 }
 
 /* This routine calculates checksums in JFFS.  */
-__u32
+static __u32
 jffs_checksum(const void *data, int size)
 {
 	__u32 sum = 0;
@@ -344,7 +370,7 @@ jffs_checksum(const void *data, int size
 }
 
 
-int
+static int
 jffs_checksum_flash(struct mtd_info *mtd, loff_t start, int size, __u32 *result)
 {
 	__u32 sum = 0;
@@ -646,7 +672,7 @@ jffs_build_fs_fail:
   a (even) higher degree of confidence in your mount process. 
   A higher number would of course slow down your mount.
 */
-int check_partly_erased_sectors(struct jffs_fmcontrol *fmc){
+static int check_partly_erased_sectors(struct jffs_fmcontrol *fmc){
 
 #define NUM_REREADS             4 /* see note above */
 #define READ_AHEAD_BYTES        4096 /* must be a multiple of 4, 
@@ -1478,7 +1504,7 @@ jffs_classify_node(struct jffs_node *nod
 
 /* Remove redundant nodes from a file.  Mark the on-flash memory
    as dirty.  */
-int
+static int
 jffs_remove_redundant_nodes(struct jffs_file *f)
 {
 	struct jffs_node *newest_node;
@@ -1532,7 +1558,7 @@ jffs_remove_redundant_nodes(struct jffs_
 
 
 /* Insert a file into the hash table.  */
-int
+static int
 jffs_insert_file_into_hash(struct jffs_file *f)
 {
 	int i = f->ino % f->c->hash_len;
@@ -1580,7 +1606,7 @@ jffs_insert_file_into_tree(struct jffs_f
 
 
 /* Remove a file from the hash table.  */
-int
+static int
 jffs_unlink_file_from_hash(struct jffs_file *f)
 {
 	D3(printk("jffs_unlink_file_from_hash(): f: 0x%p, "
@@ -2038,7 +2064,7 @@ jffs_foreach_file(struct jffs_control *c
 
 
 /* Free all nodes associated with a file.  */
-int
+static int
 jffs_free_node_list(struct jffs_file *f)
 {
 	struct jffs_node *node;
@@ -2058,7 +2084,7 @@ jffs_free_node_list(struct jffs_file *f)
 
 
 /* Free a file and its name.  */
-int
+static int
 jffs_free_file(struct jffs_file *f)
 {
 	D3(printk("jffs_free_file: f #%u, \"%s\"\n",
@@ -2073,7 +2099,7 @@ jffs_free_file(struct jffs_file *f)
 	return 0;
 }
 
-long
+static long
 jffs_get_file_count(void)
 {
 	return no_jffs_file;
@@ -2127,7 +2153,7 @@ jffs_file_count(struct jffs_file *f)
 
 /* Build up a file's range list from scratch by going through the
    version list.  */
-int
+static int
 jffs_build_file(struct jffs_file *f)
 {
 	struct jffs_node *n;
@@ -2481,7 +2507,6 @@ jffs_update_file(struct jffs_file *f, st
 	return 0;
 }
 
-
 /* Print the contents of a node.  */
 void
 jffs_print_node(struct jffs_node *n)
@@ -2541,6 +2566,7 @@ jffs_print_raw_inode(struct jffs_raw_ino
 
 
 /* Print the contents of a file.  */
+#if 0
 int
 jffs_print_file(struct jffs_file *f)
 {
@@ -2580,7 +2606,7 @@ jffs_print_file(struct jffs_file *f)
 	D(printk("}\n"));
 	return 0;
 }
-
+#endif  /*  0  */
 
 void
 jffs_print_hash_table(struct jffs_control *c)
@@ -2655,7 +2681,7 @@ jffs_print_memory_allocation_statistics(
 
 
 /* Rewrite `size' bytes, and begin at `node'.  */
-int
+static int
 jffs_rewrite_data(struct jffs_file *f, struct jffs_node *node, __u32 size)
 {
 	struct jffs_control *c = f->c;
@@ -2858,7 +2884,7 @@ retry:
    process and is often called multiple times at each occasion of a
    garbage collect.  */
 
-int
+static int
 jffs_garbage_collect_next(struct jffs_control *c)
 {
 	struct jffs_fmcontrol *fmc = c->fmc;
@@ -3097,7 +3123,7 @@ jffs_clear_end_of_node(struct jffs_contr
 } /* jffs_clear_end_of_node()  */
 
 /* Try to erase as much as possible of the dirt in the flash memory.  */
-long
+static long
 jffs_try_to_erase(struct jffs_control *c)
 {
 	struct jffs_fmcontrol *fmc = c->fmc;
@@ -3198,7 +3224,7 @@ jffs_try_to_erase(struct jffs_control *c
    collection can be.  */
 
 
-int
+static int
 jffs_garbage_collect_now(struct jffs_control *c)
 {
 	struct jffs_fmcontrol *fmc = c->fmc;
diff -puN fs/jffs/intrep.h~fs-jffs-misc-cleanups fs/jffs/intrep.h
--- 25/fs/jffs/intrep.h~fs-jffs-misc-cleanups	Thu Feb 17 17:04:36 2005
+++ 25-akpm/fs/jffs/intrep.h	Thu Feb 17 17:04:36 2005
@@ -20,9 +20,6 @@
 struct jffs_node *jffs_alloc_node(void);
 void jffs_free_node(struct jffs_node *n);
 int jffs_get_node_inuse(void);
-long jffs_get_file_count(void);
-
-__u32 jffs_checksum(const void *data, int size);
 
 void jffs_cleanup_control(struct jffs_control *c);
 int jffs_build_fs(struct super_block *sb);
@@ -36,15 +33,9 @@ struct jffs_file *jffs_find_child(struct
 void jffs_free_node(struct jffs_node *node);
 
 int jffs_foreach_file(struct jffs_control *c, int (*func)(struct jffs_file *));
-int jffs_free_node_list(struct jffs_file *f);
-int jffs_free_file(struct jffs_file *f);
 int jffs_possibly_delete_file(struct jffs_file *f);
-int jffs_build_file(struct jffs_file *f);
-int jffs_insert_file_into_hash(struct jffs_file *f);
 int jffs_insert_file_into_tree(struct jffs_file *f);
-int jffs_unlink_file_from_hash(struct jffs_file *f);
 int jffs_unlink_file_from_tree(struct jffs_file *f);
-int jffs_remove_redundant_nodes(struct jffs_file *f);
 int jffs_file_count(struct jffs_file *f);
 
 int jffs_write_node(struct jffs_control *c, struct jffs_node *node,
@@ -56,32 +47,13 @@ int jffs_read_data(struct jffs_file *f, 
 /* Garbage collection stuff.  */
 int jffs_garbage_collect_thread(void *c);
 void jffs_garbage_collect_trigger(struct jffs_control *c);
-int jffs_garbage_collect_now(struct jffs_control *c);
-
-/* Is there enough space on the flash?  */
-static inline int JFFS_ENOUGH_SPACE(struct jffs_control *c, __u32 space)
-{
-	struct jffs_fmcontrol *fmc = c->fmc;
-
-	while (1) {
-		if ((fmc->flash_size - (fmc->used_size + fmc->dirty_size)) 
-			>= fmc->min_free_size + space) {
-			return 1;
-		}
-		if (fmc->dirty_size < fmc->sector_size)
-			return 0;
-
-		if (jffs_garbage_collect_now(c)) {
-		  D1(printk("JFFS_ENOUGH_SPACE: jffs_garbage_collect_now() failed.\n"));
-		  return 0;
-		}
-	}
-}
 
 /* For debugging purposes.  */
 void jffs_print_node(struct jffs_node *n);
 void jffs_print_raw_inode(struct jffs_raw_inode *raw_inode);
+#if 0
 int jffs_print_file(struct jffs_file *f);
+#endif  /*  0  */
 void jffs_print_hash_table(struct jffs_control *c);
 void jffs_print_tree(struct jffs_file *first_file, int indent);
 
diff -puN fs/jffs/jffs_fm.c~fs-jffs-misc-cleanups fs/jffs/jffs_fm.c
--- 25/fs/jffs/jffs_fm.c~fs-jffs-misc-cleanups	Thu Feb 17 17:04:36 2005
+++ 25-akpm/fs/jffs/jffs_fm.c	Thu Feb 17 17:04:36 2005
@@ -25,6 +25,9 @@
 static int jffs_mark_obsolete(struct jffs_fmcontrol *fmc, __u32 fm_offset);
 #endif
 
+static struct jffs_fm *jffs_alloc_fm(void);
+static void jffs_free_fm(struct jffs_fm *n);
+
 extern kmem_cache_t     *fm_cache;
 extern kmem_cache_t     *node_cache;
 
@@ -602,7 +605,7 @@ jffs_mark_obsolete(struct jffs_fmcontrol
 /* check if it's possible to erase the wanted range, and if not, return
  * the range that IS erasable, or a negative error code.
  */
-long
+static long
 jffs_flash_erasable_size(struct mtd_info *mtd, __u32 offset, __u32 size)
 {
          u_long ssize;
@@ -700,7 +703,7 @@ jffs_erasable_size(struct jffs_fmcontrol
 	return (ret >= 0 ? ret : 0);
 }
 
-struct jffs_fm *jffs_alloc_fm(void)
+static struct jffs_fm *jffs_alloc_fm(void)
 {
 	struct jffs_fm *fm;
 
@@ -710,7 +713,7 @@ struct jffs_fm *jffs_alloc_fm(void)
 	return fm;
 }
 
-void jffs_free_fm(struct jffs_fm *n)
+static void jffs_free_fm(struct jffs_fm *n)
 {
 	kmem_cache_free(fm_cache,n);
 	DJM(no_jffs_fm--);
@@ -778,6 +781,7 @@ jffs_print_fm(struct jffs_fm *fm)
 	D(printk("}\n"));
 }
 
+#if 0
 void
 jffs_print_node_ref(struct jffs_node_ref *ref)
 {
@@ -787,3 +791,5 @@ jffs_print_node_ref(struct jffs_node_ref
 	D(printk("       0x%p, /* next  */\n", ref->next));
 	D(printk("}\n"));
 }
+#endif  /*  0  */
+
diff -puN fs/jffs/jffs_fm.h~fs-jffs-misc-cleanups fs/jffs/jffs_fm.h
--- 25/fs/jffs/jffs_fm.h~fs-jffs-misc-cleanups	Thu Feb 17 17:04:36 2005
+++ 25-akpm/fs/jffs/jffs_fm.h	Thu Feb 17 17:04:36 2005
@@ -64,10 +64,6 @@
 
 
 
-void jffs_free_fm(struct jffs_fm *n);
-struct jffs_fm *jffs_alloc_fm(void);
-
-
 struct jffs_node_ref
 {
 	struct jffs_node *node;
@@ -145,6 +141,8 @@ void jffs_fmfree_partly(struct jffs_fmco
 
 void jffs_print_fmcontrol(struct jffs_fmcontrol *fmc);
 void jffs_print_fm(struct jffs_fm *fm);
+#if 0
 void jffs_print_node_ref(struct jffs_node_ref *ref);
+#endif  /*  0  */
 
 #endif /* __LINUX_JFFS_FM_H__  */
diff -puN include/linux/jffs.h~fs-jffs-misc-cleanups include/linux/jffs.h
--- 25/include/linux/jffs.h~fs-jffs-misc-cleanups	Thu Feb 17 17:04:36 2005
+++ 25-akpm/include/linux/jffs.h	Thu Feb 17 17:04:36 2005
@@ -208,7 +208,6 @@ struct jffs_flash_status
 #define JFFS_MEMORY_DEBUG 0
 
 extern long no_jffs_node;
-extern long no_jffs_file;
 #if defined(JFFS_MEMORY_DEBUG) && JFFS_MEMORY_DEBUG
 extern long no_jffs_control;
 extern long no_jffs_raw_inode;
_
